@@ -1,7 +1,6 @@
 use crate::{
     backend::SchemaBuilder, prepare::*, types::*, SchemaStatementBuilder, TableForeignKey,
 };
-use std::rc::Rc;
 
 /// Drop a foreign key constraint for an existing table
 ///
@@ -28,7 +27,7 @@ use std::rc::Rc;
 #[derive(Debug, Clone)]
 pub struct ForeignKeyDropStatement {
     pub(crate) foreign_key: TableForeignKey,
-    pub(crate) table: Option<Rc<dyn Iden>>,
+    pub(crate) table: Option<DynIden>,
 }
 
 impl Default for ForeignKeyDropStatement {
@@ -57,7 +56,7 @@ impl ForeignKeyDropStatement {
     where
         T: Iden,
     {
-        self.table = Some(Rc::new(table));
+        self.table = Some(SeaRc::new(table));
         self
     }
 }
