@@ -4,7 +4,6 @@ use crate::{
 };
 #[cfg(feature = "with-json")]
 use serde_json::Value as JsonValue;
-use std::rc::Rc;
 
 /// Insert any new rows into an existing table
 ///
@@ -45,7 +44,7 @@ use std::rc::Rc;
 #[derive(Debug, Default, Clone)]
 pub struct InsertStatement {
     pub(crate) table: Option<Box<TableRef>>,
-    pub(crate) columns: Vec<Rc<dyn Iden>>,
+    pub(crate) columns: Vec<DynIden>,
     pub(crate) values: Vec<Vec<Value>>,
     pub(crate) returning: Vec<SelectExpr>,
 }
@@ -265,7 +264,7 @@ impl InsertStatement {
             let mut keys: Vec<String> = map.keys().cloned().collect();
             keys.sort();
             for k in keys.iter() {
-                self.columns.push(Rc::new(Alias::new(k)));
+                self.columns.push(SeaRc::new(Alias::new(k)));
             }
         }
         for col in self.columns.iter() {
