@@ -8,7 +8,6 @@ use crate::{
     QueryStatementBuilder,
 };
 use std::iter::FromIterator;
-use std::rc::Rc;
 
 /// Select rows from an existing table
 ///
@@ -65,7 +64,7 @@ pub enum SelectDistinct {
 #[derive(Debug, Clone)]
 pub struct SelectExpr {
     pub expr: SimpleExpr,
-    pub alias: Option<Rc<dyn Iden>>,
+    pub alias: Option<DynIden>,
 }
 
 /// Join expression used in select statement
@@ -559,10 +558,9 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use std::rc::Rc;
     /// use sea_query::{*, tests_cfg::*};
     ///
-    /// let table_as: Rc<dyn Iden> = Rc::new(Alias::new("char"));
+    /// let table_as: DynIden = SeaRc::new(Alias::new("char"));
     ///
     /// let query = Query::select()
     ///     .from_as(Char::Table, table_as.clone())
@@ -870,10 +868,9 @@ impl SelectStatement {
     /// # Examples
     ///
     /// ```
-    /// use std::rc::Rc;
     /// use sea_query::{*, tests_cfg::*};
     ///
-    /// let sub_glyph: Rc<dyn Iden> = Rc::new(Alias::new("sub_glyph"));
+    /// let sub_glyph: DynIden = SeaRc::new(Alias::new("sub_glyph"));
     /// let query = Query::select()
     ///     .column(Font::Name)
     ///     .from(Font::Table)
