@@ -1,11 +1,10 @@
 use crate::{types::*, value::*};
-use std::rc::Rc;
 
 /// Specification of a table column
 #[derive(Debug, Clone)]
 pub struct ColumnDef {
-    pub(crate) table: Option<Rc<dyn Iden>>,
-    pub(crate) name: Rc<dyn Iden>,
+    pub(crate) table: Option<DynIden>,
+    pub(crate) name: DynIden,
     pub(crate) types: Option<ColumnType>,
     pub(crate) spec: Vec<ColumnSpec>,
 }
@@ -32,7 +31,7 @@ pub enum ColumnType {
     Money(Option<(u32, u32)>),
     Json,
     JsonBinary,
-    Custom(Rc<dyn Iden>),
+    Custom(DynIden),
 }
 
 /// All column specification keywords
@@ -55,7 +54,7 @@ impl ColumnDef {
     {
         Self {
             table: None,
-            name: Rc::new(name),
+            name: SeaRc::new(name),
             types: None,
             spec: Vec::new(),
         }
@@ -301,7 +300,7 @@ impl ColumnDef {
     where
         T: Iden,
     {
-        self.types = Some(ColumnType::Custom(Rc::new(n)));
+        self.types = Some(ColumnType::Custom(SeaRc::new(n)));
         self
     }
 
@@ -310,4 +309,16 @@ impl ColumnDef {
         self.spec.push(ColumnSpec::Extra(string));
         self
     }
+
+    pub fn get_column_name(&self) -> String {
+        self.name.to_string()
+    }
+
+    pub fn get_column_type(&self) -> Option<&ColumnType> {
+        self.types.as_ref()
+    }
+
+    pub fn get_column_spec(&self) -> &Vec<ColumnSpec> {
+        self.spec.as_ref()
+    }
 }
