@@ -2,7 +2,6 @@ use crate::{
     backend::SchemaBuilder, foreign_key::*, index::*, prepare::*, types::*, ColumnDef,
     SchemaStatementBuilder,
 };
-use std::rc::Rc;
 
 /// Create a table
 ///
@@ -79,7 +78,7 @@ use std::rc::Rc;
 /// ```
 #[derive(Debug, Clone)]
 pub struct TableCreateStatement {
-    pub(crate) table: Option<Rc<dyn Iden>>,
+    pub(crate) table: Option<DynIden>,
     pub(crate) columns: Vec<ColumnDef>,
     pub(crate) options: Vec<TableOpt>,
     pub(crate) partitions: Vec<TablePartition>,
@@ -140,7 +139,7 @@ impl TableCreateStatement {
     where
         T: Iden,
     {
-        self.table = Some(Rc::new(table));
+        self.table = Some(SeaRc::new(table));
         self
     }
 
@@ -269,6 +268,22 @@ impl TableCreateStatement {
         self.partitions.push(partition);
         self
     }
+
+    pub fn get_table_name(&self) -> Option<String> {
+        self.table.as_ref().map(|table| table.to_string())
+    }
+
+    pub fn get_columns(&self) -> &Vec<ColumnDef> {
+        self.columns.as_ref()
+    }
+
+    pub fn get_foreign_key_create_stmts(&self) -> &Vec<ForeignKeyCreateStatement> {
+        self.foreign_keys.as_ref()
+    }
+
+    pub fn get_indexes(&self) -> &Vec<IndexCreateStatement> {
+        self.indexes.as_ref()
+    }
 }
 
 impl SchemaStatementBuilder for TableCreateStatement {
