@@ -1,5 +1,4 @@
 use crate::{backend::SchemaBuilder, prepare::*, types::*, SchemaStatementBuilder};
-use std::rc::Rc;
 
 /// Drop a table
 ///
@@ -28,7 +27,7 @@ use std::rc::Rc;
 /// ```
 #[derive(Debug, Clone)]
 pub struct TableDropStatement {
-    pub(crate) tables: Vec<Rc<dyn Iden>>,
+    pub(crate) tables: Vec<DynIden>,
     pub(crate) options: Vec<TableDropOpt>,
     pub(crate) if_exists: bool,
 }
@@ -61,7 +60,7 @@ impl TableDropStatement {
     where
         T: Iden,
     {
-        self.tables.push(Rc::new(table));
+        self.tables.push(SeaRc::new(table));
         self
     }
 
