@@ -5,17 +5,24 @@ fn create_1() {
     assert_eq!(
         Table::create()
             .table(Glyph::Table)
-            .col(ColumnDef::new(Glyph::Id).integer().not_null().auto_increment().primary_key())
+            .col(
+                ColumnDef::new(Glyph::Id)
+                    .integer()
+                    .not_null()
+                    .auto_increment()
+                    .primary_key()
+            )
             .col(ColumnDef::new(Glyph::Aspect).double().not_null())
             .col(ColumnDef::new(Glyph::Image).text())
             .to_string(SqliteQueryBuilder),
         vec![
             "CREATE TABLE `glyph` (",
-                "`id` integer NOT NULL PRIMARY KEY AUTOINCREMENT,",
-                "`aspect` real NOT NULL,",
-                "`image` text",
+            "`id` integer NOT NULL PRIMARY KEY AUTOINCREMENT,",
+            "`aspect` real NOT NULL,",
+            "`image` text",
             ")",
-        ].join(" ")
+        ]
+        .join(" ")
     );
 }
 
@@ -24,19 +31,26 @@ fn create_2() {
     assert_eq!(
         Table::create()
             .table(Font::Table)
-            .col(ColumnDef::new(Font::Id).integer().not_null().primary_key().auto_increment())
+            .col(
+                ColumnDef::new(Font::Id)
+                    .integer()
+                    .not_null()
+                    .primary_key()
+                    .auto_increment()
+            )
             .col(ColumnDef::new(Font::Name).string().not_null())
             .col(ColumnDef::new(Font::Variant).string().not_null())
             .col(ColumnDef::new(Font::Language).string().not_null())
             .to_string(SqliteQueryBuilder),
         vec![
             "CREATE TABLE `font` (",
-                "`id` integer NOT NULL PRIMARY KEY AUTOINCREMENT,",
-                "`name` text NOT NULL,",
-                "`variant` text NOT NULL,",
-                "`language` text NOT NULL",
+            "`id` integer NOT NULL PRIMARY KEY AUTOINCREMENT,",
+            "`name` text NOT NULL,",
+            "`variant` text NOT NULL,",
+            "`language` text NOT NULL",
             ")",
-        ].join(" ")
+        ]
+        .join(" ")
     );
 }
 
@@ -46,7 +60,13 @@ fn create_3() {
         Table::create()
             .table(Char::Table)
             .if_not_exists()
-            .col(ColumnDef::new(Char::Id).integer().not_null().auto_increment().primary_key())
+            .col(
+                ColumnDef::new(Char::Id)
+                    .integer()
+                    .not_null()
+                    .auto_increment()
+                    .primary_key()
+            )
             .col(ColumnDef::new(Char::FontSize).integer().not_null())
             .col(ColumnDef::new(Char::Character).string().not_null())
             .col(ColumnDef::new(Char::SizeW).integer().not_null())
@@ -62,15 +82,16 @@ fn create_3() {
             .to_string(SqliteQueryBuilder),
         vec![
             "CREATE TABLE IF NOT EXISTS `character` (",
-                "`id` integer NOT NULL PRIMARY KEY AUTOINCREMENT,",
-                "`font_size` integer NOT NULL,",
-                "`character` text NOT NULL,",
-                "`size_w` integer NOT NULL,",
-                "`size_h` integer NOT NULL,",
-                "`font_id` integer DEFAULT NULL,",
-                "FOREIGN KEY (`font_id`) REFERENCES `font` (`id`) ON DELETE CASCADE ON UPDATE CASCADE",
+            "`id` integer NOT NULL PRIMARY KEY AUTOINCREMENT,",
+            "`font_size` integer NOT NULL,",
+            "`character` text NOT NULL,",
+            "`size_w` integer NOT NULL,",
+            "`size_h` integer NOT NULL,",
+            "`font_id` integer DEFAULT NULL,",
+            "FOREIGN KEY (`font_id`) REFERENCES `font` (`id`) ON DELETE CASCADE ON UPDATE CASCADE",
             ")",
-        ].join(" ")
+        ]
+        .join(" ")
     );
 }
 
@@ -101,7 +122,12 @@ fn alter_1() {
     assert_eq!(
         Table::alter()
             .table(Font::Table)
-            .add_column(ColumnDef::new(Alias::new("new_col")).integer().not_null().default(99))
+            .add_column(
+                ColumnDef::new(Alias::new("new_col"))
+                    .integer()
+                    .not_null()
+                    .default(99)
+            )
             .to_string(SqliteQueryBuilder),
         "ALTER TABLE `font` ADD COLUMN `new_col` integer NOT NULL DEFAULT 99"
     );
@@ -150,4 +176,4 @@ fn alter_5() {
 #[should_panic(expected = "No alter option found")]
 fn alter_6() {
     Table::alter().to_string(SqliteQueryBuilder);
-}
\ No newline at end of file
+}
